
# pynometrics package
 pynometricss is a package for performing econometric modeling and diagnostic task. 

 # Installation

 Use the package manager [pip](https://pip.pypa.io/en/stable/) to install pynometrics

 ```bash
pip install pynometrics
```

# Usage
 ```python
 import pynometrics as ec
  ```

 ## Contributing
Pull requests are welcome. For major changes, please open an issue first to discuss what you would like to change.

Please make sure to update tests as appropriate.

## License
[MIT](https://choosealicense.com/licenses/mit/)